@@ -1,4 +1,3 @@
-static const char rcsid[]="$Id: color.c,v 1.9 1998/11/10 22:14:07 roessler Exp $";
 /*
  * Copyright (C) 1996-8 Michael R. Elkins <me@cs.hmc.edu>
  * 
@@ -176,7 +175,16 @@ static char * get_color_name (int val)
     if (Colors[i].value == val)
       return (Colors[i].name);
   }
-  return (Colors[0].name);
+
+  /* Sigh. If we got this far, the color is of the form 'colorN'
+   * Slang can handle this itself, so just return 'colorN'
+   */
+  {
+    static char color [SHORT_STRING];
+
+    snprintf (color, sizeof (color), "color%d", val);
+    return color;
+  }
 }
 #endif
 
@@ -509,7 +517,7 @@ add_pattern (COLOR_LINE **top, const char *s, int sensitive,
     {
       int i;
 
-      strfcpy(buf, tmp->pattern, sizeof(buf));
+      strfcpy(buf, NONULL(tmp->pattern), sizeof(buf));
       mutt_check_simple (buf, sizeof (buf), NONULL(SimpleSearch));
       if((tmp->color_pattern = mutt_pattern_comp (buf, M_FULL_MSG, err)) == NULL)
       {
