@@ -1,4 +1,3 @@
-static const char rcsid[]="$Id: commands.c,v 2.0 1998/12/12 08:05:52 roessler Rel $";
 /*
  * Copyright (C) 1996-8 Michael R. Elkins <me@cs.hmc.edu>
  * 
@@ -61,82 +60,16 @@ extern char *ReleaseDate;
 /* The folder the user last saved to.  Used by ci_save_message() */
 static char LastSaveFolder[_POSIX_PATH_MAX] = "";
 
-/* for compatibility with metamail */
-static int is_mmnoask (const char *buf)
-{
-  char tmp[LONG_STRING], *p, *q;
-  int lng;
-
-  if ((p = getenv ("MM_NOASK")) != NULL && *p)
-  {
-    if (mutt_strcmp (p, "1") == 0)
-      return (1);
-
-    strfcpy (tmp, p, sizeof (tmp));
-    p = tmp;
-
-    while ((p = strtok (p, ",")) != NULL)
-    {
-      if ((q = strrchr (p, '/')) != NULL)
-      {
-	if (*(q+1) == '*')
-	{
-	  if (mutt_strncasecmp (buf, p, q-p) == 0)
-	    return (1);
-	}
-	else
-	{
-	  if (mutt_strcasecmp (buf, p) == 0)
-	    return (1);
-	}
-      }
-      else
-      {
-	lng = mutt_strlen (p);
-	if (buf[lng] == '/' && mutt_strncasecmp (buf, p, lng) == 0)
-	  return (1);
-      }
-
-      p = NULL;
-    }
-  }
-
-  return (0);
-}
-
 int mutt_display_message (HEADER *cur)
 {
   char tempfile[_POSIX_PATH_MAX], buf[LONG_STRING];
   int rc = 0, builtin = 0;
-  int cmflags = M_CM_DECODE | M_CM_DISPLAY;
+  int cmflags = M_CM_DECODE | M_CM_DISPLAY | M_CM_CHARCONV;
   FILE *fpout;
 
   snprintf (buf, sizeof (buf), "%s/%s", TYPE (cur->content),
 	    cur->content->subtype);
 
-  if (cur->mailcap && !mutt_is_autoview (buf))
-  {
-    if (is_mmnoask (buf))
-      rc = M_YES;
-    else
-      rc = query_quadoption (OPT_USEMAILCAP, 
-			_("Display message using mailcap?"));
-    if (rc < 0)
-      return 0;
-    else if (rc == M_YES)
-    {
-      MESSAGE *msg;
-
-      if ((msg = mx_open_message (Context, cur->msgno)) != NULL)
-      {
-	mutt_view_attachment (msg->fp, cur->content, M_REGULAR);
-	mx_close_message (&msg);
-	mutt_set_flag (Context, cur, M_READ, 1);
-      }
-      return 0;
-    }
-  }
-
   mutt_parse_mime_message (Context, cur);
 
 
@@ -214,13 +147,17 @@ int mutt_display_message (HEADER *cur)
   }
   else
   {
+    int r;
+
     endwin ();
     snprintf (buf, sizeof (buf), "%s %s", NONULL(Pager), tempfile);
-    mutt_system (buf);
+    if ((r = mutt_system (buf)) == -1)
+      mutt_error (_("Error running \"%s\"!"), buf);
     unlink (tempfile);
     keypad (stdscr, TRUE);
-    mutt_set_flag (Context, cur, M_READ, 1);
-    if (option (OPTPROMPTAFTER))
+    if (r != -1)
+      mutt_set_flag (Context, cur, M_READ, 1);
+    if (r != -1 && option (OPTPROMPTAFTER))
     {
       mutt_ungetch (mutt_any_key_to_continue _("Command: "), 0);
       rc = km_dokey (MENU_PAGER);
@@ -285,9 +222,10 @@ void mutt_pipe_message_to_state (HEADER *h, STATE *s)
 {
   if (option (OPTPIPEDECODE))
     mutt_parse_mime_message (Context, h);
+
   mutt_copy_message (s->fpout, Context, h,
-		     option (OPTPIPEDECODE) ? M_CM_DECODE : 0,
-		     option (OPTPIPEDECODE) ? CH_FROM | CH_WEED | CH_DECODE : CH_FROM);
+		     option (OPTPIPEDECODE) ? M_CM_DECODE | M_CM_CHARCONV : 0,
+		     option (OPTPIPEDECODE) ? CH_FROM | CH_WEED | CH_DECODE | CH_REORDER : CH_FROM);
 }
 
 int mutt_pipe_message (HEADER *h)
@@ -515,14 +453,14 @@ static void set_copy_flags(HEADER *hdr, int decode, int decrypt, int *cmflags, i
   *chflags = CH_UPDATE_LEN;
   
 #ifdef _PGPPATH
-  if(!decode && decrypt && (hdr->pgp & PGPENCRYPT))
+  if (!decode && decrypt && (hdr->pgp & PGPENCRYPT))
   {
-    if(mutt_is_multipart_encrypted(hdr->content))
+    if (mutt_is_multipart_encrypted(hdr->content))
     {
       *chflags = CH_NONEWLINE | CH_XMIT | CH_MIME;
       *cmflags = M_CM_DECODE_PGP;
     }
-    else if(mutt_is_application_pgp(hdr->content) & PGPENCRYPT)
+    else if (mutt_is_application_pgp(hdr->content) & PGPENCRYPT)
       decode = 1;
   }
 #endif
@@ -530,7 +468,7 @@ static void set_copy_flags(HEADER *hdr, int decode, int decrypt, int *cmflags, i
   if(decode)
   {
     *chflags = CH_XMIT | CH_MIME | CH_TXTPLAIN;
-    *cmflags = M_CM_DECODE;
+    *cmflags = M_CM_DECODE | M_CM_CHARCONV;
   }
 
 }
@@ -703,7 +641,7 @@ static void print_msg (FILE *fp, CONTEXT *ctx, HEADER *h)
 
 
   mutt_parse_mime_message (ctx, h);
-  mutt_copy_message (fp, ctx, h, M_CM_DECODE, CH_WEED | CH_DECODE | CH_REORDER);
+  mutt_copy_message (fp, ctx, h, M_CM_DECODE | M_CM_CHARCONV, CH_WEED | CH_DECODE | CH_REORDER);
 }
 
 void mutt_print_message (HEADER *h)
