@@ -1,4 +1,3 @@
-static const char rcsid[]="$Id: hdrline.c,v 2.0 1998/12/12 08:06:20 roessler Rel $";
 /*
  * Copyright (C) 1996-8 Michael R. Elkins <me@cs.hmc.edu>
  * 
@@ -192,7 +191,8 @@ int mutt_user_is_recipient (HEADER *h)
  * %B = the list to which the letter was sent
  * %c = size of message in bytes
  * %C = current message number
- * %d = date and time of message (using strftime)
+ * %d = date and time of message using $date_format and sender's timezone
+ * %D = date and time of message using $date_format and local timezone
  * %f = entire from line
  * %F = like %n, unless from self
  * %i = message-id
@@ -295,6 +295,7 @@ hdr_format_str (char *dest,
       break;
 
     case 'd':
+    case 'D':
     case '{':
     case '[':
     case '(':
@@ -308,7 +309,7 @@ hdr_format_str (char *dest,
 
 	p = dest;
 
-	cp = (op == 'd') ? (NONULL (DateFmt)) : src;
+	cp = (op == 'd' || op == 'D') ? (NONULL (DateFmt)) : src;
 	if (*cp == '!')
 	{
 	  do_locales = 0;
@@ -318,7 +319,7 @@ hdr_format_str (char *dest,
 	  do_locales = 1;
 
 	len = destlen - 1;
-	while (len > 0 && ((op == 'd' && *cp) ||
+	while (len > 0 && (((op == 'd' || op == 'D') && *cp) ||
 			   (op == '{' && *cp != '}') || 
 			   (op == '[' && *cp != ']') ||
 			   (op == '(' && *cp != ')') ||
@@ -363,7 +364,7 @@ hdr_format_str (char *dest,
 	if (do_locales && Locale)
 	  setlocale (LC_TIME, Locale);
 
-	if (op == '[')
+	if (op == '[' || op == 'D')
 	  tm = localtime (&hdr->date_sent);
 	else if (op == '(')
 	  tm = localtime (&hdr->received);
@@ -414,8 +415,16 @@ hdr_format_str (char *dest,
       break;
 
     case 'l':
-      snprintf (fmt, sizeof (fmt), "%%%sd", prefix);
-      snprintf (dest, destlen, fmt, (int) hdr->lines);
+      if (!optional)
+      {
+	snprintf (fmt, sizeof (fmt), "%%%sd", prefix);
+	snprintf (dest, destlen, fmt, (int) hdr->lines);
+      }
+      else
+      {
+	if (hdr->lines > 0)
+	  optional = 0;
+      }
       break;
 
     case 'L':
@@ -448,8 +457,16 @@ hdr_format_str (char *dest,
       break;
 
     case 'N':
-      snprintf (fmt, sizeof (fmt), "%%%sd", prefix);
-      snprintf (dest, destlen, fmt, hdr->score);
+      if (!optional)
+      {
+	snprintf (fmt, sizeof (fmt), "%%%sd", prefix);
+	snprintf (dest, destlen, fmt, hdr->score);
+      }
+      else
+      {
+	if (hdr->score > 0)
+	  optional = 0;
+      }
       break;
 
     case 'O':
@@ -580,13 +597,11 @@ hdr_format_str (char *dest,
       break;
 
     case 'Z':
-      if (hdr->mailcap)
-	ch = 'M';
-
-
+    
+      ch = ' ';
 
 #ifdef _PGPPATH
-      else if (hdr->pgp & PGPENCRYPT)
+      if (hdr->pgp & PGPENCRYPT)
       	ch = 'P';
       else if (hdr->pgp & PGPSIGN)
         ch = 'S';
@@ -594,10 +609,6 @@ hdr_format_str (char *dest,
         ch = 'K';
 #endif
 
-
-
-      else
-	ch = ' ';
       snprintf (fmt, sizeof (fmt), "%%%ss", prefix);
       snprintf (buf2, sizeof (buf2),
 		"%c%c%c", (THREAD_NEW ? 'n' : (THREAD_OLD ? 'o' : 
