@@ -1075,16 +1075,6 @@ static int parse_set (BUFFER *tmp, BUFFER *s, unsigned long data, BUFFER *err)
   return (r);
 }
 
-void mutt_nocurses_error (const char *fmt, ...)
-{
-  va_list ap;
-
-  va_start (ap, fmt);
-  vfprintf (stderr, fmt, ap);
-  va_end (ap);
-  fputc ('\n', stderr);
-}
-
 /* reads the specified initialization file.  returns -1 if errors were found
    so that we can pause to let the user know...  */
 static int source_rc (const char *rcfile, BUFFER *err)
@@ -1632,53 +1622,6 @@ void mutt_init (int skip_sys_rc, LIST *commands)
 
   Tempdir = safe_strdup ((p = getenv ("TMPDIR")) ? p : "/tmp");
 
-  
-
-#ifdef _PGPPATH
-#ifdef _PGPV2PATH
-  PgpV2 = safe_strdup (_PGPV2PATH);
-  if ((p = getenv("PGPPATH")) != NULL)
-  {
-    snprintf (buffer, sizeof (buffer), "%s/pubring.pgp", p);
-    PgpV2Pubring = safe_strdup (buffer);
-    snprintf (buffer, sizeof (buffer), "%s/secring.pgp", p); 
-    PgpV2Secring = safe_strdup (buffer);
-  }
-  else
-  {
-    snprintf (buffer, sizeof (buffer), "%s/.pgp/pubring.pgp", NONULL(Homedir));
-    PgpV2Pubring = safe_strdup (buffer);
-    snprintf (buffer, sizeof (buffer), "%s/.pgp/secring.pgp", NONULL(Homedir));
-    PgpV2Secring = safe_strdup (buffer);
-  }
-#endif
-
-#ifdef _PGPV3PATH
-  PgpV3 = safe_strdup (_PGPV3PATH);
-  if ((p = getenv("PGPPATH")) != NULL)
-  {
-    snprintf (buffer, sizeof (buffer), "%s/pubring.pkr", p);
-    PgpV3Pubring = safe_strdup (buffer);
-    snprintf (buffer, sizeof (buffer), "%s/secring.skr", p); 
-    PgpV3Secring = safe_strdup (buffer);
-  }
-  else
-  {
-    snprintf (buffer, sizeof (buffer), "%s/.pgp/pubring.pkr", NONULL(Homedir));
-    PgpV3Pubring = safe_strdup (buffer);
-    snprintf (buffer, sizeof (buffer), "%s/.pgp/secring.skr", NONULL(Homedir));
-    PgpV3Secring = safe_strdup (buffer);
-  }
-#endif
-  
-#ifdef _PGPGPGPATH
-  PgpGpg = safe_strdup (_PGPGPGPATH);
-#endif
-
-#endif /* _PGPPATH */
-  
-  
-
 #ifdef USE_POP
   PopUser = safe_strdup (Username);
 #endif
