@@ -37,16 +37,16 @@
 #include <getopt.h>
 #endif
 
-const char ReachingUs[] = N_("\
+static const char *ReachingUs = N_("\
 To contact the developers, please mail to <mutt-dev@mutt.org>.\n");
 
-const char Notice[] = N_("\
+static const char *Notice = N_("\
 Copyright (C) 1996-9 Michael R. Elkins and others.\n\
 Mutt comes with ABSOLUTELY NO WARRANTY; for details type `mutt -vv'.\n\
 Mutt is free software, and you are welcome to redistribute it\n\
 under certain conditions; type `mutt -vv' for details.\n");
 
-const char Copyright[] = N_("\
+static const char *Copyright = N_("\
 Copyright (C) 1996-9 Michael R. Elkins <me@cs.hmc.edu>\n\
 Copyright (C) 1996-9 Brandon Long <blong@fiction.net>\n\
 Copyright (C) 1997-9 Thomas Roessler <roessler@guug.de>\n\
@@ -71,7 +71,7 @@ fixes, and suggestions.\n\
 ");
 #ifdef _PGPPATH
 
-const char ShaCopyright[] = N_("\n\
+const char* ShaCopyright = N_("\n\
 SHA1 implementation Copyright (C) 1995-7 Eric A. Young <eay@cryptsoft.com>\n\
 \n\
     Redistribution and use in source and binary forms, with or without\n\
@@ -538,7 +538,7 @@ int main (int argc, char **argv)
       for (i = optind; i < argc; i++)
 	msg->env->to = rfc822_parse_adrlist (msg->env->to, argv[i]);
 
-      if (!msg->env->to && !msg->env->cc)
+      if (option (OPTAUTOEDIT) && !msg->env->to && !msg->env->cc)
       {
 	if (!option (OPTNOCURSES))
 	  mutt_endwin (NULL);
