@@ -1,4 +1,3 @@
-static const char rcsid[]="$Id: mh.c,v 2.0 1998/12/12 08:06:41 roessler Rel $";
 /*
  * Copyright (C) 1996-8 Michael R. Elkins <me@cs.hmc.edu>
  * 
@@ -18,7 +17,8 @@ static const char rcsid[]="$Id: mh.c,v 2.0 1998/12/12 08:06:41 roessler Rel $";
  */ 
 
 /*
- * This file contains routines specific to MH and ``maildir'' style mailboxes
+ * This file contains routines specific to MH and ``maildir'' style
+ * mailboxes.
  */
 
 #include "mutt.h"
@@ -393,6 +393,7 @@ static int mh_sync_message (CONTEXT *ctx, int msgno)
     if ((f = freopen (newpath, "r", f)) != NULL)
     {
       unlink (newpath);
+      unlink (oldpath);
       if ((d = mx_open_file_lock (oldpath, "w")) != NULL)
       {
 	mutt_copy_stream (f, d);
@@ -401,6 +402,16 @@ static int mh_sync_message (CONTEXT *ctx, int msgno)
       }
       else
       {
+	/* mutt_copy_message() will have changed
+	 * some of the internal state of the message,
+	 * but we can't commit it here.
+	 * 
+	 * Reparse later.
+	 *
+	 */
+
+	mutt_free_body (&h->content->parts);
+
 	fclose (f);
 	return (-1);
       }
@@ -519,16 +530,17 @@ static int maildir_sync_message (CONTEXT *ctx, int msgno)
 int mh_sync_mailbox (CONTEXT * ctx)
 {
   char path[_POSIX_PATH_MAX], tmp[_POSIX_PATH_MAX];
-  int i, rc = 0;
+  int i, j, rc = 0;
   
   i = mh_check_mailbox(ctx, NULL);
+
+#if 0
   if(i == M_REOPENED || i == M_NEW_MAIL)
   {
-    set_option(OPTSORTCOLLAPSE);
     mutt_sort_headers(ctx, (i == M_REOPENED));
-    unset_option(OPTSORTCOLLAPSE);
   }
-  
+#endif
+
   if(i == M_REOPENED || i == M_NEW_MAIL || i < 0)
     return i;
 
@@ -557,12 +569,27 @@ int mh_sync_mailbox (CONTEXT * ctx)
 	maildir_sync_message (ctx, i);
       else
       {
-	/* FOO - seems ok to ignore errors, but might want to warn... */
+	/* XXX - seems ok to ignore errors, but might want to warn... */
 	mh_sync_message (ctx, i);
       }
     }
   }
+
+  /* XXX race condition? */
+
   maildir_update_mtime(ctx);
+
+  /* adjust indices */
+
+  if (ctx->deleted)
+  {
+    for (i = 0, j = 0; i < ctx->msgcount; i++)
+    {
+      if (!ctx->hdrs[i]->deleted)
+	ctx->hdrs[i]->index = j++;
+    }
+  }
+
   return (rc);
 }
 
@@ -600,7 +627,7 @@ int mh_check_mailbox(CONTEXT *ctx, int *index_hint)
   struct maildir *md, *p;
   struct maildir **last;
   HASH *fnames;
-  int i, deleted;
+  int i, j, deleted;
   
   if(!option (OPTCHECKNEW))
     return 0;
@@ -666,7 +693,7 @@ int mh_check_mailbox(CONTEXT *ctx, int *index_hint)
 
   /* check for modifications and adjust flags */
 
-  fnames = hash_create(1024);
+  fnames = hash_create (1031);
   
   for(p = md; p; p = p->next)
   {
@@ -765,22 +792,39 @@ int mh_check_mailbox(CONTEXT *ctx, int *index_hint)
       
       occult = 1;
 
-      if(index_hint && (i < *index_hint))
-	deleted++;
     }
-
-    if(index_hint && (i == *index_hint))
-      *index_hint -= deleted;
   }
 
-  /* dump the file name hash */
+  /* destroy the file name hash */
 
   hash_destroy(&fnames, NULL);
 
   /* If we didn't just get new mail, update the tables. */
   
   if(modified || occult)
+  {
+    short old_sort;
+    int old_count;
+
+    if (Sort != SORT_ORDER)
+    {
+      old_sort = Sort;
+      Sort = SORT_ORDER;
+      mutt_sort_headers (ctx, 1);
+      Sort = old_sort;
+    }
+  
+    old_count = ctx->msgcount;
+    for (i = 0, j = 0; i < old_count; i++)
+    {
+      if (ctx->hdrs[i]->active && index_hint && *index_hint == i)
+	*index_hint = j;
+
+      if (ctx->hdrs[i]->active)
+	ctx->hdrs[i]->index = j++;
+    }
     mx_update_tables(ctx, 0);
+  }
 
   /* Incorporate new messages */
 
