@@ -874,6 +874,7 @@ ci_send_message (int flags,		/* send mode */
   FILE *tempfp = NULL;
   BODY *pbody;
   int i, killfrom = 0;
+
 #ifdef _PGPPATH
   BODY *save_content = NULL;
   char *pgpkeylist = NULL;
@@ -1158,6 +1159,7 @@ ci_send_message (int flags,		/* send mode */
   {
 main_loop:
 
+    mutt_pretty_mailbox (fcc);
     i = mutt_compose_menu (msg, fcc, sizeof (fcc), cur);
     if (i == -1)
     {
@@ -1213,15 +1215,11 @@ main_loop:
 #ifdef _PGPPATH
   if (msg->pgp)
   {
-    if (pgp_get_keys (msg, &pgpkeylist) == -1)
-      goto main_loop;
-
-    mutt_message _("Invoking PGP...");
-    
     /* save the decrypted attachments */
     save_content = msg->content;
 
-    if (pgp_protect (msg, pgpkeylist) == -1)
+    if ((pgp_get_keys (msg, &pgpkeylist) == -1) ||
+	(pgp_protect (msg, pgpkeylist) == -1))
     {
       if (msg->content->parts)
       {
@@ -1238,12 +1236,17 @@ main_loop:
   }
 #endif /* _PGPPATH */
 
+  /* the following check may _badly_ interact with the PGP code above. */
+  
+#if 0
   if (flags & SENDEDITMSG)
   {
    int really_send = mutt_yesorno (_("Message edited. Really send?"), 1);
    if (really_send != M_YES)
      goto main_loop;
   }
+#endif
+
 
   if (!option (OPTNOCURSES) && !(flags & SENDMAILX))
     mutt_message _("Sending message...");
@@ -1252,25 +1255,16 @@ main_loop:
   encode_descriptions (msg->content);
 
   /* save a copy of the message, if necessary. */
+
   mutt_expand_path (fcc, sizeof (fcc));
   if (*fcc && mutt_strcmp ("/dev/null", fcc) != 0)
   {
-    struct stat st;
     BODY *tmpbody = msg->content;
 #ifdef _PGPPATH
     BODY *save_sig = NULL;
     BODY *save_parts = NULL;
 #endif /* _PGPPATH */
 
-    /* honor $confirmcreate and $confirmappend  in interactive mode */
-    if (!option (OPTNOCURSES) && !(flags & SENDMAILX) && 
-	!mutt_save_confirm (fcc, &st))
-    {
-      mutt_pretty_mailbox (fcc);
-      mutt_clear_error();
-      goto main_loop;
-    }
-
     /* check to see if the user wants copies of all attachments */
     if (!option (OPTFCCATTACH) && msg->content->type == TYPEMULTIPART)
     {
